@@ -1,20 +1,17 @@
 __all__ = ["MgSendSocket"]
 
-import json
 from datetime import datetime
 from os.path import dirname
-from socket import socket, AF_INET, SOCK_STREAM
+from socket import socket, SOCK_STREAM, AF_UNIX, error
 from sys import argv
 from typing import List
 
-from console_debugger.helpful.template_obj import ServerError
-from helpful.date_obj import DataForSocket
+from console_debugger.helpful.date_obj import DataForSocket, SOCKET_FILE, ServerError
 
 
 class MgSendSocket:
 
 	def __init__(self):
-		self.Host, self.Port = MgSendSocket._get_setting_socket()
 
 		# Имя файла для записи данных на случай если возникнет критическая ошибка с сервером, а очередь полная
 		self.FileNameSaveIfServerError: str = "{path_f}/save_file_name{name_f}.txt".format(
@@ -24,7 +21,7 @@ class MgSendSocket:
 
 		# Конфигурация сокета, конфигурации должны быть одинаковые между сервером и клиентов
 		self.client_sock: socket = socket(
-			family=AF_INET,
+			family=AF_UNIX,
 			type=SOCK_STREAM,
 		)
 
@@ -34,7 +31,7 @@ class MgSendSocket:
 		"""
 		try:
 			DataForSocket.SendDataObj(self.client_sock, id_, text_send)  # Отправить данные на сервер
-		except BaseException as e:
+		except error as e:
 			print(f"{e} | but data save to\n{self.FileNameSaveIfServerError}")
 			self._save_output_to_file(text_send[0])
 
@@ -44,7 +41,7 @@ class MgSendSocket:
 		"""
 
 		try:
-			self.client_sock.connect((self.Host, self.Port))
+			self.client_sock.connect(SOCKET_FILE)
 			data = self.client_sock.recv(1024)
 			# Проверка того что мы подключились именно к нужному серверу
 			if DataForSocket.CheckResponseWithServer(data):
@@ -64,14 +61,3 @@ class MgSendSocket:
 		"""
 		with open(self.FileNameSaveIfServerError, 'a', encoding='utf-8') as f:
 			f.write(data_str)
-
-	@staticmethod
-	def _get_setting_socket():
-		"""
-		Получить настройки сокета
-		"""
-		dirs = dirname(__file__).replace("\\", "/").split("/")[:-1]
-		dirs.append("setting_socket.json")
-		with open("/".join(dirs), "r") as f:
-			res = json.load(f)
-		return res["HOST"], res["PORT"]
